==> kibana-7.2.0-1-any.pkg.tar.xz: usr/share/kibana/src/legacy/ui/public/kfetch/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.__newPlatformSetup__ = __newPlatformSetup__;
Object.defineProperty(exports, "addInterceptor", {
  enumerable: true,
  get: function get() {
    return _kfetch.addInterceptor;
  }
});
Object.defineProperty(exports, "KFetchOptions", {
  enumerable: true,
  get: function get() {
    return _kfetch.KFetchOptions;
  }
});
Object.defineProperty(exports, "KFetchQuery", {
  enumerable: true,
  get: function get() {
    return _kfetch.KFetchQuery;
  }
});
exports.kfetch = void 0;

var _kfetch = require("./kfetch");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var http;
var kfetchInstance;

function __newPlatformSetup__(httpSetup) {
  if (http) {
    throw new Error('ui/kfetch already initialized with New Platform APIs');
  }

  http = httpSetup;
  kfetchInstance = (0, _kfetch.createKfetch)(http);
}

var kfetch = function kfetch(options, kfetchOptions) {
  return kfetchInstance(options, kfetchOptions);
};

exports.kfetch = kfetch;

==> kibana-7.4.0-1-any.pkg.tar.xz: usr/share/kibana/src/legacy/ui/public/kfetch/index.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
Object.defineProperty(exports, "addInterceptor", {
  enumerable: true,
  get: function get() {
    return _kfetch.addInterceptor;
  }
});
Object.defineProperty(exports, "KFetchOptions", {
  enumerable: true,
  get: function get() {
    return _kfetch.KFetchOptions;
  }
});
Object.defineProperty(exports, "KFetchQuery", {
  enumerable: true,
  get: function get() {
    return _kfetch.KFetchQuery;
  }
});
exports.kfetch = void 0;

var _new_platform = require("ui/new_platform");

var _kfetch = require("./kfetch");

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var kfetchInstance = (0, _kfetch.createKfetch)(_new_platform.npSetup.core.http);

var kfetch = function kfetch(options, kfetchOptions) {
  return kfetchInstance(options, kfetchOptions);
};

exports.kfetch = kfetch;
